@@ -197,7 +197,7 @@ def gen_exchange_siesta(
             "sisl cannot be imported. Please install sisl first.")
     fdf = sisl.get_sile(fdf_fname)
     H = fdf.read_hamiltonian()
-    if H.spin.is_colinear and False:
+    if H.spin.is_colinear and True:
         print("Reading Siesta hamiltonian: colinear spin.")
         tbmodel_up = SislWrapper(H, spin=0)
         tbmodel_dn = SislWrapper(H, spin=1)
